@@ -6,5 +6,5 @@ A package that provides structure for networks of interconnected nodes, using
 the DOT language for representation.
 '''
 
-__version__ = "0.2.2"
-from .core import Network, Connection
+__version__ = "0.3.0"
+from .core import Network, Connection, Node, graph
